"""xwlazy marker package."""

from .version import __version__, get_version, get_version_info, get_version_dict

__all__ = [
    "__version__",
    "get_version",
    "get_version_info",
    "get_version_dict",
]
